/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.bayernid.proxy.errorhandling;

import java.util.UUID;

import de.ozgcloud.common.errorhandling.ExceptionUtil;
import de.ozgcloud.common.errorhandling.TechnicalException;
import de.ozgcloud.common.grpc.GrpcUtil;
import io.grpc.Metadata;
import io.grpc.Status;
import io.grpc.StatusException;
import lombok.extern.log4j.Log4j2;
import net.devh.boot.grpc.server.advice.GrpcAdvice;
import net.devh.boot.grpc.server.advice.GrpcExceptionHandler;

@GrpcAdvice
@Log4j2
public class ExceptionHandler {

	static final String KEY_EXCEPTION_ID = "EXCEPTION_ID";

	@GrpcExceptionHandler
	public StatusException handleTechnicalException(TechnicalException e) {
		LOG.error("Technical exception occurred", e);
		return createStatusException(buildInternalStatus(e), buildMetadata(e.getExceptionId()));
	}

	@GrpcExceptionHandler
	public StatusException handleRuntimeException(RuntimeException e) {
		var exceptionId = createExceptionId();
		LOG.error(ExceptionUtil.formatMessageWithExceptionId("gRPC internal exception.",exceptionId), e);
		return createStatusException(buildInternalStatus(e), buildMetadata(exceptionId));
	}

	Status buildInternalStatus(RuntimeException e) {
		return Status.INTERNAL.withDescription(e.getMessage()).withCause(e.getCause());
	}

	String createExceptionId() {
		return UUID.randomUUID().toString();
	}

	Metadata buildMetadata(String exceptionId) {
		var metadata = new Metadata();
		metadata.put(GrpcUtil.keyOfString(KEY_EXCEPTION_ID), exceptionId);
		return metadata;
	}

	StatusException createStatusException(Status status, Metadata metadata) {
		return new StatusException(status, metadata);
	}
}
